==> haskell-hslua-packaging-2.3.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-packaging.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-Gtj35KHRWKQAAJPGU1jP4L
key:                  hslua-packaging-2.3.1-Gtj35KHRWKQAAJPGU1jP4L
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  49e9f4addc6b47c046c83f51f22073a4
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-Gtj35KHRWKQAAJPGU1jP4L
depends:
    base-4.16.4.0 containers-0.6.5.1
    hslua-core-2.3.1-CuEfKYRoupmJ3ys5gvy9E0
    hslua-marshalling-2.3.1-13lqkR0ACpwRwHEVyx5WV
    hslua-objectorientation-2.3.0-ADGSaS8bp5QHEcuc7zxfA
    hslua-typing-0.1.1-2HVJrZeEKvE82EJoNRWkAR mtl-2.2.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-packaging-2.3.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-packaging.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-EbbUiOlzXl0Gjk7opZDIfX
key:                  hslua-packaging-2.3.1-EbbUiOlzXl0Gjk7opZDIfX
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  9c9dfc71d52409aef86a173cffe86fc8
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-EbbUiOlzXl0Gjk7opZDIfX
depends:
    base-4.16.4.0 containers-0.6.5.1
    hslua-core-2.3.1-AqcWVQ7xHOm3kWrtK50zzZ
    hslua-marshalling-2.3.1-BRBIifQ0p8sHNRJh5r2GI2
    hslua-objectorientation-2.3.0-6BUg67DiP2KdjhTE56F8L
    hslua-typing-0.1.1-DbUkPI7cexvC81KoJZEhqr mtl-2.2.2 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
